==> python-mkdocs_0.14.0.orig.tar.gz: mkdocs-0.14.0/README.md <==
# MkDocs

**Project documentation with Markdown.**

[![PyPI Downloads][pypi-dl-image]][pypi-dl-link]
[![PyPI Version][pypi-v-image]][pypi-v-link]
[![Build Status][travis-image]][travis-link]
[![Windows Build Status][appveyor-image]][appveyor-link]
[![Coverage Status][codecov-image]][codecov-link]
[![Landscale Code Health][landscape-image]][landscape-link]

**See the MkDocs documentation: [www.mkdocs.org][mkdocs]**

Release notes: http://www.mkdocs.org/about/release-notes/

Project roadmap: [https://github.com/mkdocs/mkdocs/wiki][roadmap]

IRC channel: `#mkdocs` on freenode.

Discussions and support: https://groups.google.com/forum/#!forum/mkdocs

[appveyor-image]: https://img.shields.io/appveyor/ci/d0ugal/mkdocs/master.png
[appveyor-link]: https://ci.appveyor.com/project/d0ugal/mkdocs
[codecov-image]: http://codecov.io/github/mkdocs/mkdocs/coverage.svg?branch=master
[codecov-link]: http://codecov.io/github/mkdocs/mkdocs?branch=master
[landscape-image]: https://landscape.io/github/mkdocs/mkdocs/master/landscape.svg?style=flat-square
[landscape-link]: https://landscape.io/github/mkdocs/mkdocs/master
[pypi-dl-image]: https://img.shields.io/pypi/dm/mkdocs.png
[pypi-dl-link]: https://pypi.python.org/pypi/mkdocs
[pypi-v-image]: https://img.shields.io/pypi/v/mkdocs.png
[pypi-v-link]: https://pypi.python.org/pypi/mkdocs
[travis-image]: https://img.shields.io/travis/mkdocs/mkdocs/master.png
[travis-link]: https://travis-ci.org/mkdocs/mkdocs

[mkdocs]: http://www.mkdocs.org
[roadmap]: https://github.com/mkdocs/mkdocs/wiki

==> python-mkdocs_0.15.3.orig.tar.gz: mkdocs-0.15.3/README.md <==
# MkDocs

Project documentation with Markdown.

---

[![PyPI Downloads][pypi-dl-image]][pypi-dl-link]
[![PyPI Version][pypi-v-image]][pypi-v-link]
[![Build Status][travis-image]][travis-link]
[![Windows Build Status][appveyor-image]][appveyor-link]
[![Coverage Status][codecov-image]][codecov-link]
[![Landscale Code Health][landscape-image]][landscape-link]

## [See the MkDocs documentation: www.mkdocs.org][mkdocs]

Release notes: <http://www.mkdocs.org/about/release-notes/>

Project roadmap: [https://github.com/mkdocs/mkdocs/wiki][roadmap]

IRC channel: `#mkdocs` on freenode.

Discussions and support: <https://groups.google.com/forum/#!forum/mkdocs>

[appveyor-image]: https://img.shields.io/appveyor/ci/d0ugal/mkdocs/master.png
[appveyor-link]: https://ci.appveyor.com/project/d0ugal/mkdocs
[codecov-image]: http://codecov.io/github/mkdocs/mkdocs/coverage.svg?branch=master
[codecov-link]: http://codecov.io/github/mkdocs/mkdocs?branch=master
[landscape-image]: https://landscape.io/github/mkdocs/mkdocs/master/landscape.svg?style=flat-square
[landscape-link]: https://landscape.io/github/mkdocs/mkdocs/master
[pypi-dl-image]: https://img.shields.io/pypi/dm/mkdocs.png
[pypi-dl-link]: https://pypi.python.org/pypi/mkdocs
[pypi-v-image]: https://img.shields.io/pypi/v/mkdocs.png
[pypi-v-link]: https://pypi.python.org/pypi/mkdocs
[travis-image]: https://img.shields.io/travis/mkdocs/mkdocs/master.png
[travis-link]: https://travis-ci.org/mkdocs/mkdocs

[mkdocs]: http://www.mkdocs.org
[roadmap]: https://github.com/mkdocs/mkdocs/wiki
